// MouseColorPaintMenu.java - tilfjelse af en menu til MousePaintApplet
import java.awt.*;
import javax.swing.*;
import java.awt.event.*;

public class MouseColorPaintMenu {

  public static void main(String[] args) {
    JFrame frame = new JFrame("Simple Paint Menu");
    Container pane = frame.getContentPane();

    // Erklring af canvas objekt og en Mouse listener

    DrawingCanvas canvas = new DrawingCanvas();
    MouseListener mouseListener = new MouseListener();
    canvas.addMouseMotionListener(mouseListener);
    pane.add(canvas);

    // Erklring af menu bar med to hovedmenuer

    JMenuBar menuBar = new JMenuBar();
    JMenu fileMenu = new JMenu("File");
    fileMenu.setMnemonic('F');
    JMenu optionsMenu = new JMenu("Options");
    optionsMenu.setMnemonic('O');
    menuBar.add(fileMenu);
    menuBar.add(optionsMenu);
    frame.setJMenuBar(menuBar);

    //Tilfj menupunkter til fileMenu

    JMenuItem close = new JMenuItem("Close",'C');
    fileMenu.add(close);
    close.addActionListener(new Close());

    // Erklring af og tilfjelse af menupunkter til options menu

    JMenu penAdjusterMenu = new JMenu("Pen Size");
    penAdjusterMenu.setMnemonic('P');
    JMenuItem smallPen = new JMenuItem("Small",'S');
    JMenuItem mediumPen = new JMenuItem("Medium",'S');
    JMenuItem largePen = new JMenuItem("Large",'S');
    penAdjusterMenu.add(smallPen);
    penAdjusterMenu.add(mediumPen);
    penAdjusterMenu.add(largePen);

    JMenu colorMenu = new JMenu("Pen Color");
    colorMenu.setMnemonic('C');
    JMenuItem blackColor = new JMenuItem("Black",'B');
    JMenuItem redColor = new JMenuItem("Red",'R');
    JMenuItem greenColor = new JMenuItem("Green",'G');
    JMenuItem blueColor = new JMenuItem("Blue",'U');
    colorMenu.add(blackColor);
    colorMenu.add(redColor);
    colorMenu.add(greenColor);
    colorMenu.add(blueColor);

    // Tilfj listener til penstrrelse menu

    optionsMenu.add(penAdjusterMenu);
    smallPen.addActionListener(mouseListener);
    mediumPen.addActionListener(mouseListener);
    largePen.addActionListener(mouseListener);

    // Tilfj listener til farvevalg menu

    blackColor.addActionListener(mouseListener);
    redColor.addActionListener(mouseListener);
    greenColor.addActionListener(mouseListener);
    blueColor.addActionListener(mouseListener);
    optionsMenu.add(colorMenu);

    frame.pack();
    frame.show();
  }
}

class DrawingCanvas extends JComponent {
  private static final int SIZE=400;
  private Image offscreenImage;

  public void paint(Graphics canvasGraphics) {
    if (offscreenImage!=null) canvasGraphics.drawImage(offscreenImage,0,0,SIZE,SIZE,null);
  }
  public Image getOffscreenImage() {
    if (offscreenImage==null) offscreenImage = createImage(SIZE,SIZE);
    return offscreenImage;
  }
  public Dimension getMinimumSize() {
    return new Dimension(SIZE,SIZE);
  }
  public Dimension getPreferredSize() {
      return new Dimension(SIZE,SIZE);
  }
}

// MouseListener - Her udfres tegning p canvas

class MouseListener implements MouseMotionListener,ActionListener {
  protected int r=1, d=2, penColor=0;

  public void actionPerformed(ActionEvent actionEvent) {
    String action = actionEvent.getActionCommand();
    if (action.equals("Small")) r=0;
    else
      if (action.equals("Medium")) r=2;
      else
        if (action.equals("Large")) r=4;
        else
         if (action.equals("Black")) penColor=0;
         else
           if (action.equals("Red")) penColor=1;
           else
             if (action.equals("Green")) penColor=2;
             else
             if (action.equals("Blue")) penColor=3;
    if (r==0) d=1; else d=2*r;
  }

  public void mouseDragged(MouseEvent mouseEvent) {
    DrawingCanvas canvas = (DrawingCanvas)mouseEvent.getSource();
    Graphics canvasGraphics = canvas.getGraphics();
    Image image = canvas.getOffscreenImage();
    Graphics imageGraphics = image.getGraphics();

    switch (penColor) {
      case 0: imageGraphics.setColor(Color.black); break;
      case 1: imageGraphics.setColor(Color.red); break;
      case 2: imageGraphics.setColor(Color.green);  break;
      case 3: imageGraphics.setColor(Color.blue);
    }
    imageGraphics.fillOval(mouseEvent.getX()-r,mouseEvent.getY()-r,d,d);
    canvas.paint(canvasGraphics);
  }
  public void mouseMoved(MouseEvent mouseEvent) {
  }
}


class Close implements ActionListener {
  public void actionPerformed(ActionEvent actionEvent) {
    System.exit(0);
  }
}
